@@ -3,7 +3,7 @@ use Object::Pad;
 
 package OpenTelemetry::Trace::Tracer;
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use Log::Any;
 my $logger = Log::Any->get_logger( category => 'OpenTelemetry' );
@@ -62,7 +62,7 @@ class OpenTelemetry::Trace::Tracer {
         finally {
             $span->set_status(
                 $error ? ( SPAN_STATUS_ERROR, $error ) : SPAN_STATUS_OK
-            ) if $span->status->is_unset;
+            );
 
             $span->end;
         }
